@@ -10,15 +10,16 @@ our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_currency get_currencies_for_country);
 
 use File::ShareDir qw(dist_file);
-use JSON qw(decode_json);
+use Cpanel::JSON::XS;
 use Types::Serialiser;
 use Carp;
 use Data::Dumper;
+$Data::Dumper::Sortkeys = 1;
 
 my $rh_currency_for_country = {};
 
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 
 my $rh_currency_iso; # contains character strings
@@ -64,7 +65,8 @@ sub get_currency {
     my $rv = {};
     for my $key (keys %{ $rh_currency_iso->{$currency_abbreviation} }) {
         my $value = $rh_currency_iso->{$currency_abbreviation}{$key};
-        if (JSON::is_bool($value) or Types::Serialiser::is_bool($value)) {
+        if (Cpanel::JSON::XS::is_bool($value) 
+            or Types::Serialiser::is_bool($value)) {
             $value = $value ? 1 : 0;
         }
         $rv->{$key} = $value;
@@ -298,7 +300,7 @@ Data::MoneyCurrency - Get information for different currencies
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -321,7 +323,7 @@ dependency on it, the relevant data files are already included.
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =head1 EXPORT
 
@@ -352,10 +354,6 @@ reference to an array of strings that are currency codes.
     my $rv = get_currencies_for_country('fr');
     # $rv = ["eur"];
 
-=head1 AUTHOR
-
-David D Lowe, C<< <daviddlowe.flimm at gmail.com> >>
-
 =head1 BUGS
 
 Please report any bugs or feature requests through the web interface at
@@ -379,6 +377,8 @@ L<https://metacpan.org/pod/Data::MoneyCurrency>
 
 =head1 ACKNOWLEDGEMENTS
 
+Original version by David D Lowe (FLIMM)
+
 =head1 LICENSE AND COPYRIGHT
 
 This is licensed under the MIT license, and includes code from the
